@@ -1,5 +1,5 @@
 /*
- * $Id: main.c,v 1.197.2.1 2005/07/25 16:56:24 andrei Exp $
+ * $Id: main.c,v 1.197.2.2 2006/10/25 19:33:32 andrei Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -128,7 +128,7 @@
 #endif
 #include "version.h"
 
-static char id[]="@(#) $Id: main.c,v 1.197.2.1 2005/07/25 16:56:24 andrei Exp $";
+static char id[]="@(#) $Id: main.c,v 1.197.2.2 2006/10/25 19:33:32 andrei Exp $";
 static char* version=SER_FULL_VERSION;
 static char* flags=SER_COMPILE_FLAGS;
 char compiled[]= __TIME__ " " __DATE__ ;
@@ -324,6 +324,7 @@ int process_no = 0;
 
 /* cfg parsing */
 int cfg_errors=0;
+int cfg_warnings=0;
 
 /* shared memory (in MB) */
 unsigned long shm_mem_size=SHM_MEM_SIZE * 1024 * 1024;
@@ -1436,6 +1437,9 @@ try_again:
 		fprintf(stderr, "ERROR: bad config file (%d errors)\n", cfg_errors);
 		goto error;
 	}
+	if (cfg_warnings){
+		fprintf(stderr, "%d config warnings\n", cfg_warnings);
+	}
 	
 	
 	
