@@ -1,6 +1,6 @@
 /*
  *
- * $Id: acc.c,v 1.26.2.1 2005/06/14 20:25:19 janakj Exp $
+ * $Id: acc.c,v 1.26.2.2 2006/08/25 14:06:37 andrei Exp $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -288,12 +288,14 @@ static int fmt2strar( char *fmt, /* what would you like to account ? */
 				ATR(UID);
 				break;
 			case 'p': /* user part of request-uri */
-				val_arr[cnt]=rq->parsed_orig_ruri.user.len ?
+				val_arr[cnt]=((rq->parsed_uri_ok || (parse_orig_uri(rq)>=0)) &&
+								rq->parsed_orig_ruri.user.len) ?
 					& rq->parsed_orig_ruri.user : &na;
 				ATR(UP_IURI);
 				break;
 			case 'D': /* domain part of request-uri */
-				val_arr[cnt]=rq->parsed_orig_ruri.host.len ?
+				val_arr[cnt]=((rq->parsed_uri_ok || (parse_orig_uri(rq)>=0)) &&
+								rq->parsed_orig_ruri.host.len) ?
 					& rq->parsed_orig_ruri.host : &na;
 				ATR(RURI_DOMAIN);
 				break;
