@@ -1,5 +1,5 @@
 /*
- * $Id: tm.c,v 1.118.2.1 2005/02/16 23:24:14 bogdan Exp $
+ * $Id: tm.c,v 1.118.2.3 2007/01/25 16:14:49 andrei Exp $
  *
  * TM module
  *
@@ -274,6 +274,8 @@ static param_export_t params[]={
 	{"fr_timer_avp",        STR_PARAM, &fr_timer_param                       },
 	{"fr_inv_timer_avp",    STR_PARAM, &fr_inv_timer_param                   },
 	{"tw_append",           STR_PARAM|USE_FUNC_PARAM, (void*)parse_tw_append },
+    {"pass_provisional_replies", INT_PARAM, &pass_provisional_replies        },
+    {"var_timers",          INT_PARAM, &var_timers                           },
 	{0,0,0}
 };
 
