@@ -1,5 +1,5 @@
 /* 
- * $Id: msg_translator.c,v 1.137.2.1 2005/07/20 17:11:50 andrei Exp $
+ * $Id: msg_translator.c,v 1.137.2.3 2006/08/25 14:02:33 andrei Exp $
  *
  *
  * Copyright (C) 2001-2003 FhG Fokus
@@ -666,7 +666,7 @@ static inline int lumps_len(struct sip_msg* msg, struct lump* lumps, struct sock
 	else
 		send_address_str=&(send_sock->address_str);
 	if (msg->set_global_port.len)
-		send_port_str=&(msg->set_global_address);
+		send_port_str=&(msg->set_global_port);
 	else
 		send_port_str=&(send_sock->port_no_str);
 	
@@ -1018,7 +1018,7 @@ static inline void process_lumps(	struct sip_msg* msg,
 	else
 		send_address_str=&(send_sock->address_str);
 	if (msg->set_global_port.len)
-		send_port_str=&(msg->set_global_address);
+		send_port_str=&(msg->set_global_port);
 	else
 		send_port_str=&(send_sock->port_no_str);
 	
@@ -1796,7 +1796,10 @@ char * build_res_buf_from_sip_req( unsigned int code, char *text ,str *new_tag,
 					bmark->to_tag_val.s=p+(totags-hdr->name.s);
 					bmark->to_tag_val.len=
 							((struct to_body*)(hdr->parsed))->tag_value.len;
-				};
+				}else{
+					bmark->to_tag_val.s=0;
+					bmark->to_tag_val.len=0;
+				}
 			case HDR_FROM:
 			case HDR_CALLID:
 			case HDR_CSEQ:
